@@ -1,6 +1,6 @@
 #! /usr/bin/perl
 #
-# Copyright (C) 2008-2009 Alexis Bienvenue <paamc@passoire.fr>
+# Copyright (C) 2008-2011 Alexis Bienvenue <paamc@passoire.fr>
 #
 # This file is part of Auto-Multiple-Choice
 #
@@ -18,7 +18,6 @@
 # along with Auto-Multiple-Choice.  If not, see
 # <http://www.gnu.org/licenses/>.
 
-use File::Spec::Functions qw/splitpath catpath splitdir catdir catfile rel2abs tmpdir/;
 use File::Temp;
 use Getopt::Long;
 
@@ -41,8 +40,8 @@ $SIG{INT} = \&catch_signal;
 
 my $mep_dir="";
 my $cr_dir="";
-my $binaire='';
 my $debug='';
+my $debug_image_dir='';
 my $progress=0;
 my $progress_id=0;
 my $liste_f;
@@ -55,7 +54,6 @@ my $tol_marque='';
 GetOptions("mep=s"=>\$mep_dir,
 	   "mep-saved=s"=>\$mep_file,
 	   "cr=s"=>\$cr_dir,
-	   "binaire!"=>\$binaire,
 	   "seuil-coche=s"=>\$seuil_coche,
 	   "tol-marque=s"=>\$tol_marque,
 	   "debug=s"=>\$debug,
@@ -64,6 +62,7 @@ GetOptions("mep=s"=>\$mep_dir,
 	   "liste-fichiers=s"=>\$liste_f,
 	   "projet=s"=>\$rep_projet,
 	   "n-procs=s"=>\$n_procs,
+	   "debug-image-dir=s"=>\$debug_image_dir,
 	   );
 
 set_debug($debug);
@@ -87,48 +86,21 @@ if($liste_f && open(LISTE,$liste_f)) {
 
 exit(0) if($#scans <0);
 
-
-($e_volume,$e_vdirectories,$e_vfile) = splitpath( rel2abs($0) );
-sub with_prog {
-    my $fich=shift;
-    return(catpath($e_volume,$e_vdirectories,$fich));
-}
-
 sub check_rep {
     my ($r,$create)=(@_);
-    if($create && ! -x $r) {
+    if($create && $r && ! -x $r) {
 	mkdir($r);
     }
     
     die "ERROR: directory does not exist: $r" if(! -d $r);
 }
 
+$mep_dir=$rep_projet."/mep" if($rep_projet && !$mep_dir);
+$cr_dir=$rep_projet."/cr" if($rep_projet && !$cr_dir);
+
 check_rep($mep_dir);
 check_rep($cr_dir,1);
 
-# split multi-page scans
-
-my @ss=();
-
-for my $s (@scans) {
-    my $np=0;
-    if(open(ID,"-|",magick_module('identify'),$s)) {
-	while(<ID>) {
-	    if(/^($s\[[0-9]+\])/) {
-		push(@ss,$1);
-		$np++;
-	    }
-	}
-	close(ID);
-    } else {
-	debug "Identify FAILED: $! on $s";
-    }
-    debug "$np subpages for $s" if($np);
-    push @ss,$s if(!$np);
-}
-
-@scans=@ss;
-
 my $delta=$progress/(1+$#scans);
 my $fh;
 
@@ -145,16 +117,18 @@ if(!$mep_file) {
 }
 
 for my $s (@scans) {
-    my @c=with_prog("AMC-calepage.pl");
+    my $sf=$s;
+    $sf =~ s:.*/::;
+    my @c=("auto-multiple-choice","calepage");
     push @c,"--debug",debug_file();
     push @c,"--seuil-coche",$seuil_coche if($seuil_coche);
     push @c,"--tol-marque",$tol_marque if($tol_marque);
     push @c,"--progression-id",$progress_id;
     push @c,"--progression",$delta;
-    push @c,"--binaire" if($binaire);
     push @c,"--mep",$mep_dir if($mep_dir);
     push @c,"--mep-saved",$mep_file;
     push @c,"--projet",$rep_projet if($rep_projet);
+    push @c,"--debug-image",$debug_image_dir."/$sf.png" if(-d $debug_image_dir);
     push @c,"--cr",$cr_dir,$s;
 
     $queue->add_process(@c);
