@@ -128,6 +128,9 @@ my %info_vars=();
 
 sub verifie_q {
     my ($q,$t)=@_;
+
+    return() if($info_vars{'postcorrect'});
+
     if($q) {
 	if(! $q->{'mult'}) {
 	    my $oui=0;
@@ -475,7 +478,6 @@ if($mode =~ /b/) {
     # compilation en mode calibration
 
     my %bs=();
-    my %qs=();
     my %titres=();
 
     my $quest='';
@@ -505,7 +507,7 @@ if($mode =~ /b/) {
 	if(/AUTOQCM\[Q=([0-9]+)\]/) { 
 	    $quest=$1;
 	    $rep=''; 
-	    $qs{$quest}={};
+	    $bs{$etu}->{'_QUESTIONS_'}->{$quest}={};
 	}
 	if(/AUTOQCM\[ETU=([0-9]+)\]/) {
 	    $avance->progres($delta) if($etu ne '');
@@ -518,10 +520,10 @@ if($mode =~ /b/) {
 	    $titres{$1}=$2;
 	}
 	if(/AUTOQCM\[MULT\]/) { 
-	    $qs{$quest}->{'multiple'}=1;
+	    $bs{$etu}->{'_QUESTIONS_'}->{$quest}->{'multiple'}=1;
 	}
 	if(/AUTOQCM\[INDIC\]/) { 
-	    $qs{$quest}->{'indicative'}=1;
+	    $bs{$etu}->{'_QUESTIONS_'}->{$quest}->{'indicative'}=1;
 	}
 	if(/AUTOQCM\[REP=([0-9]+):([BM])\]/) {
 	    $rep=$1;
@@ -536,6 +538,9 @@ if($mode =~ /b/) {
 	if(/AUTOQCM\[BD(S|M)=([^\]]+)\]/) {
 	    $bs{'defaut'}->{"$1."}->{-bareme}=$2;
 	}
+	if(/AUTOQCM\[VAR:([0-9a-zA-Z.-]+)=([^\]]+)\]/) {
+	    $info_vars{$1}=$2;
+	}
     }
     close(AMCLOG);
     $cmd_pid='';
@@ -555,14 +560,20 @@ if($mode =~ /b/) {
     $writer->xmlDecl($encodage_interne);
 
     my %opts=(src=>$f_tex,
-	      version=>$VERSION_BAREME);
+	      version=>$VERSION_BAREME,
+	      postcorrect=>$info_vars{'postcorrect'},
+	);
 
-    $opts{'main'}=$bs{''}->{'.'}->{-bareme} if($bs{''}->{'.'}->{-bareme});
+    $opts{'main'}=$bs{0}->{'.'}->{-bareme} if($bs{0}->{'.'}->{-bareme});
 
     $writer->startTag('bareme',%opts);
 
     for my $etu (grep { $_ ne '' } (keys %bs)) {
-	$writer->startTag('etudiant',id=>$etu);
+	%opts=(id=>$etu);
+	$opts{'main'}=$bs{$etu}->{'.'}->{-bareme}
+	    if($bs{$etu}->{'.'}->{-bareme});
+
+	$writer->startTag('etudiant',%opts);
 
 	my $bse=$bs{$etu};
 	my @q_ids=();
@@ -572,12 +583,12 @@ if($mode =~ /b/) {
 				  bareme=>$bse->{"$q."}->{-bareme});
 	    }
 	} else {
-	    for my $q (keys %qs) {
+	    for my $q (keys %{$bs{$etu}->{'_QUESTIONS_'}}) {
 		$writer->startTag('question',id=>$q,
 				  titre=>$titres{$q},
 				  bareme=>$bse->{"$q."}->{-bareme},
-				  indicative=>$qs{$q}->{'indicative'},
-				  multiple=>$qs{$q}->{'multiple'},
+				  indicative=>$bs{$etu}->{'_QUESTIONS_'}->{$q}->{'indicative'},
+				  multiple=>$bs{$etu}->{'_QUESTIONS_'}->{$q}->{'multiple'},
 		    );
 		
 		for my $i (keys %$bse) {
